@@ -91,6 +91,16 @@ target_ip_is_local = False
 project_toml_file_path = "./mio.toml"
 
 
+warning_regexes = ["UVM_WARNING(?! \: )"]
+error_regexes   = ["UVM_ERROR(?! \: )"]
+fatal_regexes   = ["UVM_FATAL(?! \: )"]
+viv_fatal_errors  = ["FATAL_ERROR\:"]
+mdc_fatal_errors  = ["FATAL_ERROR\:", "=F:"]
+vcs_fatal_errors  = ["FATAL_ERROR\:"] # TODO Replace with correct string
+qst_fatal_errors  = ["FATAL_ERROR\:"] # TODO Replace with correct string
+xcl_fatal_errors  = ["FATAL_ERROR\:"] # TODO Replace with correct string
+riv_fatal_errors  = ["FATAL_ERROR\:"] # TODO Replace with correct string
+
 
 def set_pwd(wd):
     global pwd
