@@ -138,7 +138,12 @@ def install_ip_and_deps(vendor, name, global_install, username="", password=""):
         common.banner(f"Installing IP '{vendor}/{name}'")
         install_ip(vendor, name, global_install, username, password)
         cache.scan_and_load_ip_metadata()
-        ip = cache.get_ip(vendor, name)
+        if vendor == "":
+            ip = cache.get_anon_ip(name)
+        else:
+            ip = cache.get_ip(vendor, name)
+        if ip == None:
+            common.fatal(f"Failed to install '{vendor}/{name}'")
     
     ip.delete_dependencies()
     cache.scan_and_load_ip_metadata()
